//go:generate go-bindata-assetfs ui/ ui/css/

//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package main

import (
	"net"
	"net/http"
	"time"

	"github.com/gorilla/mux"
	"gitlab.servus.at/autoradio/tank/api/v1"
)

const (
	WebUIPathPrefix = "/ui/"
	WebAPIv1Prefix  = "/api/v1/"
)

func runWeb(ln net.Listener) error {
	r := mux.NewRouter()

	r.Handle("/", http.RedirectHandler(WebUIPathPrefix, http.StatusSeeOther))
	r.PathPrefix(WebUIPathPrefix).Handler(http.StripPrefix(WebUIPathPrefix, http.FileServer(assetFS())))

	v1.InstallHandler(r.PathPrefix(WebAPIv1Prefix).Subrouter())

	srv := &http.Server{
		Handler:      r,
		WriteTimeout: 12 * time.Hour,
		ReadTimeout:  12 * time.Hour,
	}
	return srv.Serve(ln)
}
